package com.jz.dmp.modules.controller.sys;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.annotation.SysOperationLogAnnotation;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.constant.CommConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.StatuConstant;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberDto;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRequest;
import com.jz.dmp.modules.model.DmpMember;
import com.jz.dmp.modules.service.sys.DmpMemberService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;

/**
 * 用户表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/member")
@Api(tags = "用户表")
public class DmpMemberController {
	
	@Autowired
	private DmpMemberService dmpMemberService;
	
	/**列表查询用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findListWithPage")
	@ApiOperation(value = "分頁列表查询用户表", notes = "分頁列表查询用户表")
	public BaseBeanResponse<Map<String, Object>> findListWithPage(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<Map<String, Object>> baseBeanResponse = new BaseBeanResponse<>();
		try {
			baseBeanResponse = dmpMemberService.findListWithPage(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**列表查询用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findList")
	@ApiOperation(value = "列表查询用户表", notes = "列表查询用户表")
	public BaseBeanResponse<DmpMemberDto> findList(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<DmpMemberDto>();
		try {
			baseBeanResponse = dmpMemberService.findList(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	
	/**主键查询用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/view")
	//@ApiOperation(value = "主键查询用户表", notes = "主键查询用户表")
	public BaseBeanResponse<DmpMemberDto> view(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<DmpMemberDto>();
		try {
			baseBeanResponse = dmpMemberService.findById(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**获取登录用户信息
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/getLoginUserInfo")
	@ApiOperation(value = "获取登录用户信息", notes = "获取登录用户信息")
	public BaseBeanResponse<DmpMemberDto> getLoginUserInfo(HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<DmpMemberDto>();
		try {
			baseBeanResponse = dmpMemberService.getLoginUserInfo(httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**删除用户表
	 * @param userId
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.GET, value = "/delete")
	//@ApiOperation(value = "删除用户表", notes = "删除用户表")
	//@ApiImplicitParam(name = "ids", value = "用户表主键集（逗号隔开）")
	public BaseResponse delete(@RequestParam(name = "ids", required = true ) String ids, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			//参数封装
			String[] idStrs = ids.split(",");
			List<Integer> idList = Arrays.asList(idStrs).stream().map(x->{
				return Integer.parseInt(x);
			}).collect(Collectors.toList());
			
			baseResponse = dmpMemberService.deleteByIds(idList, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**软删除用户表
	 * @param userId
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/softDelete")
	@ApiOperation(value = "软删除用户表", notes = "软删除用户表")
	@ApiImplicitParam(name = "ids", value = "用户表主键集（逗号隔开）")
	@SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_DELETE, descrption = "软删除用户表", optModular = CommConstant.MODULAR_WORKSPACEMANG_MEMBER, isProjOpt = false)
	public BaseResponse softDelete(@RequestParam(name = "ids", required = true ) String ids, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			//参数封装
			String[] idStrs = ids.split(",");
			List<Integer> idList = Arrays.asList(idStrs).stream().map(x->{
				return Integer.parseInt(x);
			}).collect(Collectors.toList());
			
			baseResponse = dmpMemberService.softDeleteByIds(idList, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("软删除失败");
			baseResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**新增用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/add")
	@ApiOperation(value = "新增用户表", notes = "新增用户表")
	@SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_ADD, descrption = "新增用户", optModular = CommConstant.MODULAR_WORKSPACEMANG_MEMBER, isProjOpt = false)
	public BaseBeanResponse<DmpMember> add(@RequestBody DmpMember dmpMember, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<DmpMember>();
		try {
			baseBeanResponse = dmpMemberService.add(dmpMember, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**批量新增用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/addBatch")
	//@ApiOperation(value = "批量新增用户表", notes = "批量新增用户表")
	public BaseBeanResponse<DmpMemberBatch> addBatch(@RequestBody DmpMemberBatch dmpMemberBatch, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberBatch> baseBeanResponse = new BaseBeanResponse<DmpMemberBatch>();
		try {
			baseBeanResponse = dmpMemberService.addBatch(dmpMemberBatch, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("批量新增失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**修改用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	//@RequestMapping(method = RequestMethod.POST, value = "/edit")
	//@ApiOperation(value = "修改用户表", notes = "修改用户表")
	public BaseBeanResponse<DmpMember> edit(@RequestBody DmpMember dmpMember, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<DmpMember>();
		try {
			baseBeanResponse = dmpMemberService.edit(dmpMember, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("修改失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**用户项目切换
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/switchProj")
	@ApiImplicitParam(name = "projectId", value = "项目主键")
	@ApiOperation(value = "用户项目切换", notes = "用户项目切换")
	@SysOperationLogAnnotation(actionType = CommConstant.OPT_TYPE_EDIT, descrption = "用户项目切换", optModular = CommConstant.MODULAR_WORKSPACEMANG_MEMBER, isProjOpt = true)
	public BaseBeanResponse<DmpMember> switchProj(@RequestParam(name = "projectId", required = true) Integer projectId, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<DmpMember>();
		try {
			baseBeanResponse = dmpMemberService.switchProj(projectId, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("项目切换失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**获取项目下不是成员的所有用户
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/findListUnChoose")
	@ApiOperation(value = "获取项目下不是成员的所有用户", notes = "获取项目下不是成员的所有用户")
	@ApiImplicitParam(name = "projectId", value = "项目主键")
	public BaseBeanResponse<DmpMemberDto> findListUnChoose(@RequestParam(name = "projectId", required = true) Integer projectId, HttpServletRequest httpRequest){
		//封装参数
		DmpMemberRequest dmpMemberRequest = new DmpMemberRequest();
		dmpMemberRequest.setUnChooseProjId(projectId);
		
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<DmpMemberDto>();
		try {
			baseBeanResponse = dmpMemberService.findList(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("查询失败");
			baseBeanResponse.setCode(StatuConstant.FAILURE_CODE);
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
